==> schlix-cms-v2.2.8-3.zip: schlix/system/apps/search/config.template.php <==
<?php
if (!defined('SCHLIX_VERSION'))
    die('No Access');
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//
// SCHLIX WEB CONTENT MANAGEMENT SYSTEM - Copyright (C) SCHLIX WEB INC.
// License: GPLv3
// 
// Please read the license for details
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//
$app_list = $this->getListofApplications('apps');
$forbidden_apps = ['core','admin','search','sitemanager','personaldatarequest','users','landing','tag'];
?>
<?php global $SystemConfig, $CurrentUser; ?>

<schlix-config:data-editor   data-schlix-controller="SCHLIX.CMS.SearchAdmin">

        <schlix-config:save-result />
        <x-ui:schlix-editor-form id="form-edit-config" method="post" data-config-action="save" action="<?= $this->createFriendlyAdminURL('action=saveconfig') ?>" autocomplete="off">

            <schlix-config:action-buttons />
            <x-ui:csrf />

            <x-ui:schlix-tab-container>
                <!-- tab -->
                <x-ui:schlix-tab id="tab_general" fonticon="far fa-file" label="<?= ___('General') ?>"> 
                    <!--content -->
                        
                       <schlix-config:app_alias   config-default-value="<?= strtolower($this->schlix_master_class) ?>" />
                        <schlix-config:app_description   />
                        <schlix-config:textbox config-key="str_meta_keywords" label="<?= ___('Default Meta Keywords') ?>"   config-fonticon="fa fa-hashtag" />
                        <schlix-config:textbox config-key="str_meta_description" label="<?= ___('Default Meta Description') ?>"   config-fonticon="fa fa-hashtag" />
                        
                        
                        <schlix-config:checkboxgroup config-key="array_enabled_apps" label="<?=  ___('Enable Search for the following applications') ?>">
                            <?php foreach ($app_list as $enabled_app): ?>
                            <?php if (!in_array($enabled_app['value'], $forbidden_apps)): ?>
                                <schlix-config:option value='<?= $enabled_app['value'] ?>'><?= ___h($enabled_app['label']) ?></schlix-config:option>
                                <?php endif ?>
                            <?php endforeach ?>
                        </schlix-config:checkboxgroup>
                                            <!-- end content -->
                </x-ui:schlix-tab>
                <!-- tab -->
                <x-ui:schlix-tab id="tab_permissions" fonticon="fa fa-users" label="<?= ___('Permissions') ?>">
                    <!--content -->
                    <schlix-config:permission-usergroups config-key="array_groups_allowed_for_backend_access" label="<?=  ___('Enable backend access for the following user groups') ?>" />
                    <p><?= ___('Administrators will always be allowed to access to the backend, regardless of the settings above. If nothing is specified, all users who already have access to the backend can access this extension.'); ?></p>
                    <!-- end content -->
                    
                </x-ui:schlix-tab>                
                <!-- end -->
            </x-ui:schlix-tab-container>
            
        </x-ui:schlix-editor-form>
</schlix-config:data-editor>

==> schlix-cms-v2.2.9-2.zip: schlix/system/apps/search/config.template.php <==
<?php
if (!defined('SCHLIX_VERSION'))
    die('No Access');
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//
// SCHLIX WEB CONTENT MANAGEMENT SYSTEM - Copyright (C) SCHLIX WEB INC.
// License: GPLv3
// 
// Please read the license for details
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//
$app_list = $this->getListofApplications('apps');
$forbidden_apps = ['core','admin','search','sitemanager','personaldatarequest','users','landing','tag'];
?>
<?php global $SystemConfig, $CurrentUser; ?>

<schlix-config:data-editor   data-schlix-controller="SCHLIX.CMS.SearchAdmin">

        <schlix-config:save-result />
        <x-ui:schlix-editor-form id="form-edit-config" method="post" data-config-action="save" action="<?= $this->createFriendlyAdminURL('action=saveconfig') ?>" autocomplete="off">

            <schlix-config:action-buttons />
            <x-ui:csrf />

            <x-ui:schlix-tab-container>
                <!-- tab -->
                <x-ui:schlix-tab id="tab_general" fonticon="far fa-file" label="<?= ___('General') ?>"> 
                    <!--content -->
                        
                       <schlix-config:app_alias   config-default-value="<?= strtolower($this->schlix_master_class) ?>" />
                        <schlix-config:app_description   />
                        <schlix-config:textbox config-key="str_meta_keywords" label="<?= ___('Default Meta Keywords') ?>"   config-fonticon="fa fa-hashtag" />
                        <schlix-config:textbox config-key="str_meta_description" label="<?= ___('Default Meta Description') ?>"   config-fonticon="fa fa-hashtag" />
                        
                        
                        <schlix-config:checkboxgroup config-key="array_enabled_apps" label="<?=  ___('Enable Search for the following applications') ?>">
                            <?php foreach ($app_list as $enabled_app): ?>
                            <?php if (!in_array($enabled_app['value'], $forbidden_apps)): ?>
                                <schlix-config:option value='<?= $enabled_app['value'] ?>'><?= ___h($enabled_app['label']) ?></schlix-config:option>
                                <?php endif ?>
                            <?php endforeach ?>
                        </schlix-config:checkboxgroup>
                                            <!-- end content -->
                </x-ui:schlix-tab>
                <!-- tab -->
                <x-ui:schlix-tab id="tab_permissions" fonticon="fa fa-users" label="<?= ___('Permissions') ?>">
                    <!--content -->
                    <schlix-config:permission-backend-access config-key="array_groups_allowed_for_backend_access" label="<?=  ___('Enable backend access for the following user groups') ?>" />
                    <p><?= ___('Administrators will always be allowed to access to the backend, regardless of the settings above. If nothing is specified, all users who already have access to the backend can access this extension.'); ?></p>
                    <!-- end content -->
                    
                </x-ui:schlix-tab>                
                <!-- end -->
            </x-ui:schlix-tab-container>
            
        </x-ui:schlix-editor-form>
</schlix-config:data-editor>
